@@ -24,8 +24,9 @@ from tableauhyperapi import HyperProcess, Telemetry, \
 
 class TableauHyperApiExtraLogic:
     locale = None
+    supported_input_file_types = ('csv', 'json', 'parquet', 'pickle')
 
-    def __init__(self, in_language='en_US'):
+    def __init__(self, in_language):
         file_parts = os.path.normpath(os.path.abspath(__file__)).replace('\\', os.path.altsep)\
             .split(os.path.altsep)
         locale_domain = file_parts[(len(file_parts)-1)].replace('.py', '')
